<?php
// $Id: galleryformatter.theme.inc,v 1.1.2.5 2010/05/16 16:41:37 manuelgarcia Exp $

/**
 * @file
 * Provides theme preprocess for the galleryformatter default formatter
 */

/**
 * Preprocess function for galleryformatter.tpl.php
 */
function template_preprocess_galleryformatter_formatter_galleryformatter_default(&$vars) {
  // grab the widget settings for for both image cache presets we will be using later
  $widget = galleryformatter_get_field_settings($vars['element']['#field_name']);
  $thumb_preset = $widget['thumb_preset'];
  $slide_preset = $widget['slide_preset'];
  $style = $widget['style'];

  // ONLY do something if both of these presets are set for this field
  if (isset($thumb_preset) && ($thumb_preset !== '0') && isset($slide_preset) && ($slide_preset !== '0')) {
    $vars['fieldname'] = $vars['element']['#field_name'];
    $children = element_children($vars['element']);
    foreach ($children as $key) {
      $items[] = $vars['element'][$key]['#item'];
    }
    // Setup our arrays of variables for the template file to use
    foreach ($items as $id => $field) {
      // Grab and sanitize image information
      $description = check_plain($field['data']['description']);
      $title = check_plain($field['data']['title']);
      $filename = $field['filename'];
      $filepath = $field['filepath'];

      // default alt attribute is a good thing
      $alt = ($field['data']['alt']) ? check_plain($field['data']['alt']) : $filename;
      $img_attributes = array('alt' => $alt, );

      // prepare slides
      $slides[$id]['image'] = theme('imagecache', $slide_preset, $filepath, $filename, $title, $img_attributes);
      $slides[$id]['title'] = $title;
      $slides[$id]['description'] = $description ;
      $slides[$id]['filepath'] = $filepath;

      // link the slides to the original image if so configured
      $vars['link_to_full'] = $widget['link_to_full']; // let the tpl know if we are liking or not
      if ($widget['link_to_full'] == TRUE) {
        $vars['gallery_style'] = 'galleryformatter-view-full '; // give the gallery a class for themers to play with
        $link_attributes = array(
          'title' => $title,
        );
        // integration with other modules for jQuery modal windows
        if (module_exists('colorbox')) {
          $link_attributes['class'] .= ' colorbox';
        }
        if (module_exists('thickbox')) {
          $link_attributes['class'] .= ' thickbox';
        }
        if (module_exists('shadowbox')) {
          $link_attributes['rel'] = 'shadowbox';
        }
        if (module_exists('lightbox2')) {
          $link_attributes['rel'] = 'lightbox';
        }
        // link the slide image and include the span for the icon
        $slides[$id]['image'] = l('<span class="galleryformatter-view-full">'. t('View the full image') .'</span>'. $slides[$id]['image'], $filepath, array('attributes' => $link_attributes, 'html' => TRUE,));
      } // END linking to original

      // setup thumbnail images
      $thumbs[$id] = theme('imagecache', $thumb_preset, $filepath, $filename, $title, $img_attributes);
    }

    // insert into the variables for the template file
    $vars['gallery_thumbs'] = $thumbs;
    $vars['gallery_slides'] = $slides;

    // Get the images width and height for use by the template
    $image_path = $slides[0]['filepath']; // the first image will be used to get the dimensions of the gallery
    $slide_dimensions = galleryformatter_getimage_dimensions($slide_preset, $image_path);
    $thumb_dimensions = galleryformatter_getimage_dimensions($thumb_preset, $image_path);
    $vars['gallery_slide_height'] = $slide_dimensions['height'];
    $vars['gallery_slide_width'] = $slide_dimensions['width'];
    $vars['gallery_thumb_height'] = $thumb_dimensions['height'];
    $vars['gallery_thumb_width'] = $thumb_dimensions['width'];

    // setup the style class
    $vars['gallery_style'] .= 'galleryformatter-'. drupal_strtolower($style);

    // add the necessary JS and CSS files
    $modulepath = drupal_get_path('module', 'galleryformatter');
    /**
     * @todo:
     * Give our js some settings maybe
     * Give users some options on click vs. hover?
     */
/*
    $settings = array();
    $settings['galleryformatter']['settingname'] = 'settingvalue';
    drupal_add_js($settings, 'setting');
*/
    drupal_add_js($modulepath .'/theme/infiniteCarousel.js');
    drupal_add_js($modulepath .'/theme/galleryformatter.js');
    galleryformatter_add_css($style);
  }

  // account for any preset not selected and provide a link to configure them
  else {
    $destination = drupal_get_destination();
    $configure_path = 'admin/content/node-type/'. $vars['element']['#type_name'] .'/fields/'. $vars['element']['#field_name'];
    $configure_link = l($vars['element']['#field_name'], $configure_path, (array('query' => $destination)));
    drupal_set_message('Please select both a thumbnail and slide presets in your Gallery Formatter settings for '. $configure_link .'. The jQuery gallery needs these settings to work.', 'warning');
  }
}
